@@ -318,7 +318,13 @@ renv_bootstrap_install <- function(version, tarball, library) {
   bin <- R.home("bin")
   exe <- if (Sys.info()[["sysname"]] == "Windows") "R.exe" else "R"
   r <- file.path(bin, exe)
-  args <- c("--vanilla", "CMD", "INSTALL", "--no-multiarch", "-l", shQuote(library), shQuote(tarball))
+
+  args <- c(
+    "--vanilla", "CMD", "INSTALL", "--no-multiarch",
+    "-l", shQuote(path.expand(library)),
+    shQuote(path.expand(tarball))
+  )
+
   output <- system2(r, args, stdout = TRUE, stderr = TRUE)
   message("Done!")
 
@@ -693,7 +699,8 @@ renv_bootstrap_project_type <- function(path) {
 }
 
 renv_bootstrap_user_dir <- function() {
-  chartr("\\", "/", renv_bootstrap_user_dir_impl())
+  dir <- renv_bootstrap_user_dir_impl()
+  path.expand(chartr("\\", "/", dir))
 }
 
 renv_bootstrap_user_dir_impl <- function() {
