@@ -6,11 +6,12 @@ test_that("the version of renv in a project can be changed (upgraded)", {
   skip_on_cran()
   skip_sometimes()
 
-  renv_tests_scope("breakfast")
-  renv::init()
-  renv::load()
+  renv_tests_scope()
 
-  quietly(renv::upgrade(version = "0.5.0"))
+  init()
+  load()
+
+  upgrade(version = "0.5.0")
 
   project <- getwd()
   expect_equal(renv_activate_version(project), "0.5.0")
